@@ -9,11 +9,13 @@ from matplotlib.testing.decorators import cleanup
 import pytest
 
 import cartopy.crs as ccrs
-from cartopy.tests.mpl import ImageTesting
+from cartopy.tests.mpl import ImageTesting, MPL_VERSION
 
 
 @pytest.mark.natural_earth
-@ImageTesting(["igh_land"])
+@ImageTesting(["igh_land"],
+              tolerance=(3.6 if MPL_VERSION.release[:2] < (3, 5)
+                         or ccrs.PROJ_VERSION < (9, 0, 1) else 0.5))
 def test_igh_land():
     crs = ccrs.InterruptedGoodeHomolosine(emphasis="land")
     ax = plt.axes(projection=crs)
@@ -22,7 +24,9 @@ def test_igh_land():
 
 
 @pytest.mark.natural_earth
-@ImageTesting(["igh_ocean"])
+@ImageTesting(["igh_ocean"],
+              tolerance=(4.5 if MPL_VERSION.release[:2] < (3, 5)
+                         or ccrs.PROJ_VERSION < (9, 0, 1) else 0.5))
 def test_igh_ocean():
     crs = ccrs.InterruptedGoodeHomolosine(
         central_longitude=-160, emphasis="ocean"
